@@ -1,10 +1,14 @@
 import logging
 import os
+from binascii import unhexlify
 from os import path
+from typing import Any, Optional
 
-from erdpy import errors
-from erdpy.wallet import bech32, pem, generate_pair
-from erdpy import utils
+from erdpy import constants, errors, utils
+from erdpy.errors import LedgerError
+from erdpy.interfaces import IAccount, IAddress
+from erdpy.wallet import bech32, generate_pair, pem
+from erdpy.wallet.keyfile import get_password, load_from_key_file
 
 logger = logging.getLogger("accounts")
 
@@ -40,32 +44,50 @@ class AccountsRepository:
         return accounts
 
 
-class Account:
-    def __init__(self, address=None, pem_file=None):
-        self.private_key_seed = None
+class Account(IAccount):
+    def __init__(self,
+                 address: Any = None,
+                 pem_file: Optional[str] = None,
+                 pem_index: int = 0,
+                 key_file: str = "",
+                 pass_file: str = "",
+                 ledger: bool = False):
         self.address = Address(address)
         self.pem_file = pem_file
-        self.nonce = 0
+        self.pem_index = int(pem_index)
+        self.nonce: int = 0
+        self.ledger = ledger
 
-        if pem_file:
-            seed, pubkey = pem.parse(pem_file)
+        if self.pem_file:
+            seed, pubkey = pem.parse(self.pem_file, self.pem_index)
             self.private_key_seed = seed.hex()
             self.address = Address(pubkey)
+        elif key_file and pass_file:
+            password = get_password(pass_file)
+            address_from_key_file, seed = load_from_key_file(key_file, password)
+            self.private_key_seed = seed.hex()
+            self.address = Address(address_from_key_file)
 
-    def sync_nonce(self, proxy):
-        logger.info(f"Account.sync_nonce()")
+    def sync_nonce(self, proxy: Any):
+        logger.info("Account.sync_nonce()")
         self.nonce = proxy.get_account_nonce(self.address)
         logger.info(f"Account.sync_nonce() done: {self.nonce}")
 
+    def get_seed(self) -> bytes:
+        if self.ledger:
+            raise LedgerError("cannot get seed from a Ledger account")
+        return unhexlify(self.private_key_seed)
 
-class Address:
+
+class Address(IAddress):
     HRP = "erd"
     PUBKEY_LENGTH = 32
     PUBKEY_STRING_LENGTH = PUBKEY_LENGTH * 2    # hex-encoded
     BECH32_LENGTH = 62
+    _value_hex: str
 
     def __init__(self, value):
-        self._value_hex = None
+        self._value_hex = ''
 
         if not value:
             return
@@ -84,29 +106,34 @@ class Address:
         else:
             raise errors.BadAddressFormatError(value)
 
-    def hex(self):
+    def hex(self) -> str:
         self._assert_validity()
         return self._value_hex
 
-    def bech32(self):
+    def bech32(self) -> str:
         self._assert_validity()
         pubkey = self.pubkey()
-        return bech32.bech32_encode(self.HRP, bech32.convertbits(pubkey, 8, 5))
+        b32 = bech32.bech32_encode(self.HRP, bech32.convertbits(pubkey, 8, 5))
+        assert isinstance(b32, str)
+        return b32
 
     def pubkey(self):
         self._assert_validity()
         pubkey = bytes.fromhex(self._value_hex)
         return pubkey
 
+    def is_contract_address(self):
+        return self.hex().startswith(constants.SC_HEX_PUBKEY_PREFIX)
+
     def _assert_validity(self):
-        if self._value_hex is None:
+        if self._value_hex == '':
             raise errors.EmptyAddressError()
 
     def __repr__(self):
         return self.bech32()
 
     @classmethod
-    def zero(cls):
+    def zero(cls) -> 'Address':
         return Address("0" * 64)
 
 
@@ -121,5 +148,5 @@ def _decode_bech32(value):
     hrp, value_bytes = bech32.bech32_decode(bech32_string)
     if hrp != Address.HRP:
         raise errors.BadAddressFormatError(value)
-    decodedBytes = bech32.convertbits(value_bytes, 5, 8, False)
-    return bytearray(decodedBytes)
+    decoded_bytes = bech32.convertbits(value_bytes, 5, 8, False)
+    return bytearray(decoded_bytes)
