@@ -13,12 +13,15 @@ import erdpy.cli_cost
 import erdpy.cli_data
 import erdpy.cli_deps
 import erdpy.cli_dispatcher
+import erdpy.cli_ledger
 import erdpy.cli_network
 import erdpy.cli_testnet
 import erdpy.cli_transactions
 import erdpy.cli_validators
 import erdpy.cli_wallet
-from erdpy import errors, scope
+import erdpy.cli_delagation
+import erdpy.cli_dns
+from erdpy import config, errors, scope
 from erdpy._version import __version__
 
 logger = logging.getLogger("cli")
@@ -29,18 +32,20 @@ def main():
         _do_main()
     except errors.KnownError as err:
         logger.critical(err.get_pretty())
-        sys.exit(1)
+        return 1
     except KeyboardInterrupt:
         print("erdpy process killed by user.")
-        sys.exit(1)
+        return 1
+    return 0
 
 
 def _do_main():
     logging.basicConfig(level=logging.INFO)
     scope.initialize()
 
-    parser = setup_parser()
-    args = parser.parse_args()
+    argv_with_config_args = config.add_config_args(sys.argv[1:])
+    parser = setup_parser(argv_with_config_args)
+    args = parser.parse_args(argv_with_config_args)
 
     if args.verbose:
         logging.basicConfig(level=logging.DEBUG)
@@ -53,7 +58,7 @@ def _do_main():
         args.func(args)
 
 
-def setup_parser():
+def setup_parser(args: List[str] = sys.argv[1:]):
     parser = ArgumentParser(
         prog="erdpy",
         usage="erdpy [-h] [-v] [--verbose] COMMAND-GROUP [-h] COMMAND ...",
@@ -79,20 +84,23 @@ https://docs.elrond.com/tools/erdpy.
     subparsers = parser.add_subparsers()
     commands: List[Any] = []
 
-    commands.append(erdpy.cli_contracts.setup_parser(subparsers))
-    commands.append(erdpy.cli_transactions.setup_parser(subparsers))
-    commands.append(erdpy.cli_validators.setup_parser(subparsers))
+    commands.append(erdpy.cli_contracts.setup_parser(args, subparsers))
+    commands.append(erdpy.cli_transactions.setup_parser(args, subparsers))
+    commands.append(erdpy.cli_validators.setup_parser(args, subparsers))
     commands.append(erdpy.cli_accounts.setup_parser(subparsers))
-    commands.append(erdpy.cli_wallet.setup_parser(subparsers))
+    commands.append(erdpy.cli_ledger.setup_parser(subparsers))
+    commands.append(erdpy.cli_wallet.setup_parser(args, subparsers))
     commands.append(erdpy.cli_network.setup_parser(subparsers))
     commands.append(erdpy.cli_cost.setup_parser(subparsers))
-    commands.append(erdpy.cli_dispatcher.setup_parser(subparsers))
+    commands.append(erdpy.cli_dispatcher.setup_parser(args, subparsers))
     commands.append(erdpy.cli_blockatlas.setup_parser(subparsers))
     commands.append(erdpy.cli_deps.setup_parser(subparsers))
     commands.append(erdpy.cli_config.setup_parser(subparsers))
     commands.append(erdpy.cli_block.setup_parser(subparsers))
-    commands.append(erdpy.cli_testnet.setup_parser(subparsers))
+    commands.append(erdpy.cli_testnet.setup_parser(args, subparsers))
     commands.append(erdpy.cli_data.setup_parser(subparsers))
+    commands.append(erdpy.cli_delagation.setup_parser(args, subparsers))
+    commands.append(erdpy.cli_dns.setup_parser(args, subparsers))
 
     parser.epilog = """
 ----------------------
@@ -106,4 +114,5 @@ COMMAND GROUPS summary
 
 
 if __name__ == "__main__":
-    main()
+    ret = main()
+    sys.exit(ret)
