@@ -2,11 +2,13 @@ import argparse
 import ast
 import sys
 from argparse import FileType
-from typing import Any, List, Text
+from typing import Any, List, Text, cast
 
 from erdpy import config, errors, scope, utils
 from erdpy.accounts import Account
+from erdpy.ledger.ledger_functions import do_get_ledger_address
 from erdpy.proxy.core import ElrondProxy
+from erdpy.transactions import Transaction
 
 
 def wider_help_formatter(prog: Text):
@@ -47,16 +49,17 @@ def add_command_subparser(subparsers: Any, group: str, command: str, description
     )
 
 
-def add_tx_args(sub: Any, with_nonce: bool = True, with_receiver: bool = True, with_data: bool = True, with_estimate_gas: bool = False):
+def add_tx_args(args: List[str], sub: Any, with_nonce: bool = True, with_receiver: bool = True, with_data: bool = True, with_estimate_gas: bool = False):
     if with_nonce:
-        sub.add_argument("--nonce", type=int, required=not("--recall-nonce" in sys.argv), help="# the nonce for the transaction")
+        sub.add_argument("--nonce", type=int, required=not("--recall-nonce" in args), help="# the nonce for the transaction")
         sub.add_argument("--recall-nonce", action="store_true", default=False, help="⭮ whether to recall the nonce when creating the transaction (default: %(default)s)")
 
     if with_receiver:
         sub.add_argument("--receiver", required=True, help="🖄 the address of the receiver")
+        sub.add_argument("--receiver-username", required=False, help="🖄 the username of the receiver")
 
     sub.add_argument("--gas-price", default=config.DEFAULT_GAS_PRICE, help="⛽ the gas price (default: %(default)d)")
-    sub.add_argument("--gas-limit", required=not("--estimate-gas" in sys.argv), help="⛽ the gas limit")
+    sub.add_argument("--gas-limit", required=not("--estimate-gas" in args), help="⛽ the gas limit")
     if with_estimate_gas:
         sub.add_argument("--estimate-gas", action="store_true", default=False, help="⛽ whether to estimate the gas limit (default: %(default)d)")
 
@@ -67,17 +70,22 @@ def add_tx_args(sub: Any, with_nonce: bool = True, with_receiver: bool = True, w
 
     sub.add_argument("--chain", default=scope.get_chain_id(), help="the chain identifier (default: %(default)s)")
     sub.add_argument("--version", type=int, default=scope.get_tx_version(), help="the transaction version (default: %(default)s)")
+    sub.add_argument("--options", type=int, default=0, help="the transaction options (default: 0)")
 
 
-def add_wallet_args(sub: Any):
-    sub.add_argument("--pem", required=not (utils.is_arg_present("--keyfile", sys.argv)), help="🔑 the PEM file, if keyfile not provided")
+def add_wallet_args(args: List[str], sub: Any):
+    sub.add_argument("--pem", required=check_if_sign_method_required(args, "--pem"), help="🔑 the PEM file, if keyfile not provided")
     sub.add_argument("--pem-index", default=0, help="🔑 the index in the PEM file (default: %(default)s)")
-    sub.add_argument("--keyfile", required=not (utils.is_arg_present("--pem", sys.argv)), help="🔑 a JSON keyfile, if PEM not provided")
-    sub.add_argument("--passfile", required=not (utils.is_arg_present("--pem", sys.argv)), help="🔑 a file containing keyfile's password, if keyfile provided")
+    sub.add_argument("--keyfile", required=check_if_sign_method_required(args, "--keyfile"), help="🔑 a JSON keyfile, if PEM not provided")
+    sub.add_argument("--passfile", required=(utils.is_arg_present(args, "--keyfile")), help="🔑 a file containing keyfile's password, if keyfile provided")
+    sub.add_argument("--ledger", action="store_true", required=check_if_sign_method_required(args, "--ledger"), default=False, help="🔐 bool flag for signing transaction using ledger")
+    sub.add_argument("--ledger-account-index", type=int, default=0, help="🔐 the index of the account when using Ledger")
+    sub.add_argument("--ledger-address-index", type=int, default=0, help="🔐 the index of the address when using Ledger")
+    sub.add_argument("--sender-username", required=False, help="🖄 the username of the sender")
 
 
 def add_proxy_arg(sub: Any):
-    sub.add_argument("--proxy", default=scope.get_proxy(), help="🖧 the URL of the proxy (default: %(default)s)")
+    sub.add_argument("--proxy", default=scope.get_proxy(), help="🔗 the URL of the proxy (default: %(default)s)")
 
 
 def add_outfile_arg(sub: Any, what: str = ""):
@@ -97,7 +105,7 @@ def add_omit_fields_arg(sub: Any):
 def parse_omit_fields_arg(args: Any) -> List[str]:
     literal = args.omit_fields
     parsed = ast.literal_eval(literal)
-    return parsed
+    return cast(List[str], parsed)
 
 
 def prepare_nonce_in_args(args: Any):
@@ -106,6 +114,9 @@ def prepare_nonce_in_args(args: Any):
             account = Account(pem_file=args.pem, pem_index=args.pem_index)
         elif args.keyfile and args.passfile:
             account = Account(key_file=args.keyfile, pass_file=args.passfile)
+        elif args.ledger:
+            address = do_get_ledger_address(account_index=args.ledger_account_index, address_index=args.ledger_address_index)
+            account = Account(address=address)
         else:
             raise errors.NoWalletProvided()
 
@@ -113,14 +124,39 @@ def prepare_nonce_in_args(args: Any):
         args.nonce = account.nonce
 
 
-def add_broadcast_args(sub: Any):
+def add_broadcast_args(sub: Any, simulate=True, relay=False):
     sub.add_argument("--send", action="store_true", default=False, help="✓ whether to broadcast the transaction (default: %(default)s)")
-    sub.add_argument("--simulate", action="store_true", default=False, help="whether to simulate the transaction (default: %(default)s)")
-    sub.add_argument("--relay", action="store_true", default=False, help="whether to relay the transaction (default: %(default)s)")
+
+    if simulate:
+        sub.add_argument("--simulate", action="store_true", default=False, help="whether to simulate the transaction (default: %(default)s)")
+    if relay:
+        sub.add_argument("--relay", action="store_true", default=False, help="whether to relay the transaction (default: %(default)s)")
 
 
 def check_broadcast_args(args: Any):
-    if args.relay and args.send:
+    if hasattr(args, "relay") and args.relay and args.send:
         raise errors.BadUsage("Cannot directly send a relayed transaction. Use 'erdpy tx new --relay' first, then 'erdpy tx send --data-file'")
     if args.send and args.simulate:
         raise errors.BadUsage("Cannot both 'simulate' and 'send' a transaction")
+
+
+def send_or_simulate(tx: Transaction, args: Any):
+    if args.send:
+        tx.send(ElrondProxy(args.proxy))
+    elif args.simulate:
+        response = tx.simulate(ElrondProxy(args.proxy))
+        utils.dump_out_json(response)
+
+
+def check_if_sign_method_required(args: List[str], checked_method: str) -> bool:
+    methods = ["--pem", "--keyfile", "--ledger"]
+    rest_of_methods = []
+    for method in methods:
+        if method != checked_method:
+            rest_of_methods.append(method)
+
+    for method in rest_of_methods:
+        if utils.is_arg_present(args, method):
+            return False
+
+    return True
