@@ -1,36 +1,45 @@
 import base64
 import logging
-from typing import Any, List
+from typing import Any, List, Optional
 
 from Cryptodome.Hash import keccak
 
-from erdpy import config, errors, utils
-from erdpy.accounts import Address
+from erdpy import config, constants, errors
+from erdpy.accounts import Account, Address
+from erdpy.interfaces import IElrondProxy
 from erdpy.transactions import Transaction
+from erdpy.utils import Object
 
 logger = logging.getLogger("contracts")
 
-VM_TYPE_ARWEN = "0500"
+HEX_PREFIX = "0X"
+
+
+class QueryResult(Object):
+    def __init__(self, as_base64: str, as_hex: str, as_number: int):
+        self.base64 = as_base64
+        self.hex = as_hex
+        self.number = as_number
 
 
 class SmartContract:
-    def __init__(self, address=None, bytecode=None, metadata=None):
+    def __init__(self, address: Optional[Address] = None, bytecode=None, metadata=None):
         self.address = Address(address)
         self.bytecode = bytecode
         self.metadata = metadata or CodeMetadata()
 
-    def deploy(self, owner, arguments, gas_price, gas_limit, value, chain, version) -> Transaction:
+    def deploy(self, owner: Account, arguments: List[Any], gas_price: int, gas_limit: int, value: int, chain: str, version: int) -> Transaction:
         self.owner = owner
         self.compute_address()
 
         arguments = arguments or []
         gas_price = int(gas_price)
         gas_limit = int(gas_limit)
-        value = str(value or "0")
+        value = value or 0
 
         tx = Transaction()
         tx.nonce = owner.nonce
-        tx.value = value
+        tx.value = str(value)
         tx.sender = owner.address.bech32()
         tx.receiver = Address.zero().bech32()
         tx.gasPrice = gas_price
@@ -42,8 +51,8 @@ class SmartContract:
         tx.sign(owner)
         return tx
 
-    def prepare_deploy_transaction_data(self, arguments):
-        tx_data = f"{self.bytecode}@{VM_TYPE_ARWEN}@{self.metadata.to_hex()}"
+    def prepare_deploy_transaction_data(self, arguments: List[Any]):
+        tx_data = f"{self.bytecode}@{constants.VM_TYPE_ARWEN}@{self.metadata.to_hex()}"
 
         for arg in arguments:
             tx_data += f"@{_prepare_argument(arg)}"
@@ -61,17 +70,17 @@ class SmartContract:
         address = bytes([0] * 8) + bytes([5, 0]) + address[10:30] + owner_bytes[30:]
         self.address = Address(address)
 
-    def execute(self, caller, function, arguments, gas_price, gas_limit, value, chain, version) -> Transaction:
+    def execute(self, caller: Account, function: str, arguments: List[str], gas_price: int, gas_limit: int, value: int, chain: str, version: int) -> Transaction:
         self.caller = caller
 
         arguments = arguments or []
         gas_price = int(gas_price)
         gas_limit = int(gas_limit)
-        value = str(value or "0")
+        value = value or 0
 
         tx = Transaction()
         tx.nonce = caller.nonce
-        tx.value = value
+        tx.value = str(value)
         tx.sender = caller.address.bech32()
         tx.receiver = self.address.bech32()
         tx.gasPrice = gas_price
@@ -83,7 +92,7 @@ class SmartContract:
         tx.sign(caller)
         return tx
 
-    def prepare_execute_transaction_data(self, function, arguments):
+    def prepare_execute_transaction_data(self, function: str, arguments: List[Any]):
         tx_data = function
 
         for arg in arguments:
@@ -91,17 +100,17 @@ class SmartContract:
 
         return tx_data
 
-    def upgrade(self, owner, arguments, gas_price, gas_limit, value, chain, version) -> Transaction:
+    def upgrade(self, owner: Account, arguments: List[Any], gas_price: int, gas_limit: int, value: int, chain: str, version: int) -> Transaction:
         self.owner = owner
 
         arguments = arguments or []
         gas_price = int(gas_price or config.DEFAULT_GAS_PRICE)
         gas_limit = int(gas_limit)
-        value = str(value or "0")
+        value = value or 0
 
         tx = Transaction()
         tx.nonce = owner.nonce
-        tx.value = value
+        tx.value = str(value)
         tx.sender = owner.address.bech32()
         tx.receiver = self.address.bech32()
         tx.gasPrice = gas_price
@@ -113,7 +122,7 @@ class SmartContract:
         tx.sign(owner)
         return tx
 
-    def prepare_upgrade_transaction_data(self, arguments):
+    def prepare_upgrade_transaction_data(self, arguments: List[Any]):
         tx_data = f"upgradeContract@{self.bytecode}@{self.metadata.to_hex()}"
 
         for arg in arguments:
@@ -121,22 +130,37 @@ class SmartContract:
 
         return tx_data
 
-    def query(self, proxy, function, arguments) -> List[Any]:
+    def query(
+        self,
+        proxy: IElrondProxy,
+        function: str,
+        arguments: List[Any],
+        value: int = 0,
+        caller: Optional[Address] = None
+    ) -> List[Any]:
+        response_data = self.query_detailed(proxy, function, arguments, value, caller)
+        return_data = response_data.get("returnData", []) or response_data.get("ReturnData", [])
+        return [self._interpret_return_data(data) for data in return_data]
+
+    def query_detailed(self, proxy: IElrondProxy, function: str, arguments: List[Any], value: int = 0, caller: Optional[Address] = None) -> Any:
         arguments = arguments or []
         prepared_arguments = [_prepare_argument(argument) for argument in arguments]
 
         payload = {
-            "ScAddress": self.address.bech32(),
-            "FuncName": function,
-            "Args": prepared_arguments
+            "scAddress": self.address.bech32(),
+            "funcName": function,
+            "args": prepared_arguments,
+            "value": str(value)
         }
 
+        if caller:
+            payload["caller"] = caller.bech32()
+
         response = proxy.query_contract(payload)
         response_data = response.get("data", {})
-        return_data = response_data.get("returnData", response_data.get("ReturnData"))
-        return [self._interpret_return_data(data) for data in return_data]
+        return response_data
 
-    def _interpret_return_data(self, data):
+    def _interpret_return_data(self, data: str) -> Any:
         if not data:
             return data
 
@@ -145,36 +169,50 @@ class SmartContract:
             as_hex = as_bytes.hex()
             as_number = int(as_hex, 16)
 
-            result = utils.Object()
-            result.base64 = data
-            result.hex = as_hex
-            result.number = as_number
+            result = QueryResult(data, as_hex, as_number)
             return result
         except Exception:
             logger.warn(f"Cannot interpret return data: {data}")
             return None
 
 
-def _prepare_argument(argument):
-    hex_prefix = "0X"
+def _prepare_argument(argument: Any):
     as_string = str(argument).upper()
 
-    if as_string.startswith(hex_prefix):
-        return as_string[len(hex_prefix):]
+    if as_string.startswith(HEX_PREFIX):
+        return _prepare_hexadecimal(as_string)
 
-    if not as_string.isnumeric():
-        raise errors.UnknownArgumentFormat(as_string)
+    return _prepare_decimal(as_string)
 
-    as_number = int(as_string)
-    as_hexstring = hex(as_number)[len(hex_prefix):]
-    if len(as_hexstring) % 2 == 1:
-        as_hexstring = "0" + as_hexstring
 
+def _prepare_hexadecimal(argument: str) -> str:
+    argument = argument[len(HEX_PREFIX):]
+    argument = ensure_even_length(argument)
+    try:
+        _ = int(argument, 16)
+    except ValueError:
+        raise errors.UnknownArgumentFormat(argument)
+    return argument
+
+
+def _prepare_decimal(argument: str) -> str:
+    if not argument.isnumeric():
+        raise errors.UnknownArgumentFormat(argument)
+
+    as_number = int(argument)
+    as_hexstring = hex(as_number)[len(HEX_PREFIX):]
+    as_hexstring = ensure_even_length(as_hexstring)
     return as_hexstring
 
 
+def ensure_even_length(string: str) -> str:
+    if len(string) % 2 == 1:
+        return '0' + string
+    return string
+
+
 class CodeMetadata:
-    def __init__(self, upgradeable=True, payable=False):
+    def __init__(self, upgradeable: bool = True, payable: bool = False):
         self.upgradeable = upgradeable
         self.payable = payable
 
