@@ -3,7 +3,7 @@ from typing import Any
 from os import path
 
 from erdpy.validators.validators_file import ValidatorsFile
-from erdpy.conv.conv import Converters
+from erdpy import utils
 from erdpy.accounts import Account
 from erdpy.config import MetaChainSystemSCsCost
 from erdpy.validators.core import estimate_system_sc_call
@@ -15,8 +15,8 @@ DELEGATION_MANAGER_SC_ADDRESS = "erd1qqqqqqqqqqqqqqqpqqqqqqqqqqqqqqqqqqqqqqqqqqq
 
 def prepare_args_for_create_new_staking_contract(args: Any):
     args.data = 'createNewDelegationContract'
-    args.data += '@' + Converters.str_int_to_hex_str(str(args.total_delegation_cap))
-    args.data += '@' + Converters.str_int_to_hex_str(str(args.service_fee))
+    args.data += '@' + utils.str_int_to_hex_str(str(args.total_delegation_cap))
+    args.data += '@' + utils.str_int_to_hex_str(str(args.service_fee))
 
     args.receiver = DELEGATION_MANAGER_SC_ADDRESS
 
@@ -57,33 +57,33 @@ def prepare_args_for_remove_nodes(args: Any):
 
 
 def prepare_args_for_stake_nodes(args: Any):
-    parsed_keys, num_keys = Converters.parse_keys(args.bls_keys)
+    parsed_keys, num_keys = utils.parse_keys(args.bls_keys)
     args.data = 'stakeNodes' + parsed_keys
     args.receiver = args.delegation_contract
 
     if args.estimate_gas:
-        args.gas_limit = estimate_system_sc_call(args, MetaChainSystemSCsCost.DELEGATION_OPS
-                                                 + MetaChainSystemSCsCost.STAKE, num_keys + 1)
+        cost = MetaChainSystemSCsCost.DELEGATION_OPS + MetaChainSystemSCsCost.STAKE
+        args.gas_limit = estimate_system_sc_call(args, cost, num_keys + 1)
 
 
 def prepare_args_for_unbond_nodes(args: Any):
-    parsed_keys, num_keys = Converters.parse_keys(args.bls_keys)
+    parsed_keys, num_keys = utils.parse_keys(args.bls_keys)
     args.data = 'unBondNodes' + parsed_keys
     args.receiver = args.delegation_contract
 
     if args.estimate_gas:
-        args.gas_limit = estimate_system_sc_call(args, MetaChainSystemSCsCost.DELEGATION_OPS
-                                                 + MetaChainSystemSCsCost.UNBOND, num_keys + 1)
+        cost = MetaChainSystemSCsCost.DELEGATION_OPS + MetaChainSystemSCsCost.UNBOND
+        args.gas_limit = estimate_system_sc_call(args, cost, num_keys + 1)
 
 
 def prepare_args_for_unstake_nodes(args: Any):
-    parsed_keys, num_keys = Converters.parse_keys(args.bls_keys)
+    parsed_keys, num_keys = utils.parse_keys(args.bls_keys)
     args.data = 'unStakeNodes' + parsed_keys
     args.receiver = args.delegation_contract
 
     if args.estimate_gas:
-        args.gas_limit = estimate_system_sc_call(args, MetaChainSystemSCsCost.DELEGATION_OPS
-                                                 + MetaChainSystemSCsCost.UNSTAKE, num_keys + 1)
+        cost = MetaChainSystemSCsCost.DELEGATION_OPS + MetaChainSystemSCsCost.UNSTAKE
+        args.gas_limit = estimate_system_sc_call(args, cost, num_keys + 1)
 
 
 def prepare_args_for_unjail_nodes(args: Any):
@@ -91,7 +91,7 @@ def prepare_args_for_unjail_nodes(args: Any):
 
 
 def _prepare_args(command: str, args: Any):
-    parsed_keys, num_keys = Converters.parse_keys(args.bls_keys)
+    parsed_keys, num_keys = utils.parse_keys(args.bls_keys)
     args.data = command + parsed_keys
     args.receiver = args.delegation_contract
 
@@ -101,7 +101,7 @@ def _prepare_args(command: str, args: Any):
 
 def prepare_args_change_service_fee(args: Any):
     data = 'changeServiceFee'
-    data += '@' + Converters.str_int_to_hex_str(str(args.service_fee))
+    data += '@' + utils.str_int_to_hex_str(str(args.service_fee))
 
     args.data = data
     args.receiver = args.delegation_contract
@@ -111,7 +111,7 @@ def prepare_args_change_service_fee(args: Any):
 
 def prepare_args_modify_delegation_cap(args: Any):
     data = 'modifyTotalDelegationCap'
-    data += '@' + Converters.str_int_to_hex_str(str(args.delegation_cap))
+    data += '@' + utils.str_int_to_hex_str(str(args.delegation_cap))
 
     args.data = data
     args.receiver = args.delegation_contract
