@@ -130,7 +130,17 @@ class TransactionQueue:
         while idx < len(txs):
             tx = txs[idx]
             # TODO CHECK IF BUNCH OF TRANSACTION generate transactions with chain id and version
-            bunch.add(owner, tx["receiver"], nonce, tx["value"], tx["data"], tx["gasPrice"], tx["gasLimit"])
+            bunch.add(
+                owner,
+                tx.get("receiver"),
+                nonce,
+                tx.get("value"),
+                tx.get("data"),
+                tx.get("gasPrice"),
+                tx.get("gasLimit"),
+                tx.get("chain"),
+                tx.get("version")
+            )
             # increment nonce
             nonce += 1
             idx += 1
