@@ -22,6 +22,9 @@ class ITransaction:
     def serialize(self) -> bytes:
         return bytes()
 
+    def serialize_as_inner(self) -> str:
+        return ''
+
     def to_dictionary(self) -> Dict[str, Any]:
         return {}
 
@@ -36,8 +39,14 @@ class IElrondProxy:
     def send_transaction(self, payload: Any) -> str:
         return ""
 
+    def simulate_transaction(self, payload: Any) -> str:
+        return ""
+
     def send_transactions(self, payload: List[Any]) -> Tuple[int, List[str]]:
         return 0, []
 
-    def send_transaction_and_wait_for_result(self, payload: Any, num_seconds_timeout) -> str:
-        return ""
+    def send_transaction_and_wait_for_result(self, payload: Any, num_seconds_timeout: int) -> Dict[str, Any]:
+        return dict()
+
+    def query_contract(self, payload: Any) -> Any:
+        return dict()
