@@ -1,7 +1,10 @@
+from erdpy import dependencies
 import logging
 from os import path
+from typing import Any, Dict
+from pathlib import Path
 
-from erdpy import dependencies, errors, utils, guards
+from erdpy import errors, utils, guards
 from erdpy.projects import shared
 from erdpy.projects.project_clang import ProjectClang
 from erdpy.projects.project_cpp import ProjectCpp
@@ -26,7 +29,7 @@ def load_project(directory):
         raise errors.NotSupportedProject(directory)
 
 
-def build_project(directory, options):
+def build_project(directory: str, options: Dict[str, Any]):
     directory = path.expanduser(directory)
 
     logger.info("build_project.directory: %s", directory)
@@ -34,10 +37,21 @@ def build_project(directory, options):
 
     guards.is_directory(directory)
     project = load_project(directory)
-    project.build(options)
+    output_wasm_file = project.build(options)
+    logger.info("Build ran.")
+    relative_wasm_path = output_wasm_file.relative_to(Path.cwd())
+    logger.info(f"WASM file generated: {relative_wasm_path}")
 
 
-def run_tests(args):
+def clean_project(directory: str):
+    directory = path.expanduser(directory)
+    guards.is_directory(directory)
+    project = load_project(directory)
+    project.clean()
+    logger.info("Project cleaned.")
+
+
+def run_tests(args: Any):
     project = args.project
     directory = args.directory
     wildcard = args.wildcard
