@@ -1,5 +1,6 @@
 import logging
 import os
+from pathlib import Path
 import subprocess
 from os import path
 
@@ -67,7 +68,7 @@ class ProjectCpp(Project):
             str(self.file_o),
             "-o", self.find_file_globally("*.cpp").with_suffix(".wasm"),
             "--strip-all",
-            f"--allow-undefined",
+            "--allow-undefined",
             "--demangle"
         ]
 
@@ -79,12 +80,13 @@ class ProjectCpp(Project):
 
         myprocess.run_process(args)
 
-    def _copy_build_artifacts_to_output(self):
+    def _do_after_build(self) -> Path:
         source_file = self.find_file_globally("*.cpp")
-        self._copy_to_output(source_file.with_suffix(".wasm"))
+        output_wasm_file = self._copy_to_output(source_file.with_suffix(".wasm"))
         os.remove(source_file.with_suffix(".wasm"))
         os.remove(source_file.with_suffix(".ll"))
         os.remove(source_file.with_suffix(".o"))
+        return output_wasm_file
 
     def _get_llvm_path(self):
         return dependencies.get_module_directory("llvm")
