@@ -1,8 +1,8 @@
 import shutil
+import time
 from os import path
 
 from erdpy import downloader, errors, utils, workstation
-from erdpy.projects import shared
 
 
 class TemplatesRepository:
@@ -13,15 +13,27 @@ class TemplatesRepository:
         self.relative_path = relative_path
 
     def download(self):
-        archive = self._get_archive_path()
-        downloader.download(self.url, archive)
+        self._download_if_old()
+
         templates_folder = self.get_folder()
         try:
             shutil.rmtree(templates_folder)
         except FileNotFoundError:
             pass
+
+        archive = self._get_archive_path()
         utils.unzip(archive, templates_folder)
 
+    def _download_if_old(self):
+        CACHE_DURATION = 30
+        archive = self._get_archive_path()
+
+        if path.isfile(archive):
+            if time.time() - path.getmtime(archive) < CACHE_DURATION:
+                return
+
+        downloader.download(self.url, archive)
+
     def _get_archive_path(self):
         tools_folder = workstation.get_tools_folder()
         archive = path.join(tools_folder, f"{self.key}.zip")
@@ -38,13 +50,21 @@ class TemplatesRepository:
         return has
 
     def get_template_folder(self, template):
-        return path.join(self.get_folder(), self.relative_path,  template)
+        return path.join(self.get_folder(), self.relative_path, template)
 
     def get_templates(self):
         folder = path.join(self.get_folder(), self.relative_path)
         templates = utils.get_subfolders(folder)
+        templates = [item for item in templates if self.is_template(item)]
         return templates
 
+    def is_template(self, subfolder):
+        elrond_json_file = self.get_metadata_file(subfolder)
+        return path.isfile(elrond_json_file)
+
+    def get_metadata_file(self, template_folder):
+        return path.join(self.get_folder(), self.relative_path, template_folder, "elrond.json")
+
     def copy_template(self, template, destination_path):
         if not self.has_template(template):
             raise errors.TemplateMissingError(template)
@@ -53,12 +73,6 @@ class TemplatesRepository:
         shutil.copytree(source_path, destination_path)
 
     def get_language(self, template):
-        directory = self.get_template_folder(template)
-
-        if shared.is_source_clang(directory):
-            return "C / C++"
-        if shared.is_source_sol(directory):
-            return "Solidity"
-        if shared.is_source_rust(directory):
-            return "Rust"
-        return "unknown"
+        metadata_file = self.get_metadata_file(template)
+        metadata = utils.read_json_file(metadata_file)
+        return metadata.get("language", "unknown")
