@@ -1,8 +1,9 @@
 import logging
 import time
-from typing import Any, List, Tuple
+from typing import Any, List, Tuple, cast, Dict
 
 from erdpy.accounts import Address
+from erdpy.interfaces import IAddress, IElrondProxy
 from erdpy.proxy.http_facade import do_get, do_post
 from erdpy.proxy.messages import NetworkConfig
 
@@ -12,23 +13,23 @@ ANY_SHARD_ID = 0
 logger = logging.getLogger("proxy")
 
 
-class ElrondProxy:
+class ElrondProxy(IElrondProxy):
     def __init__(self, url: str):
         self.url = url
 
-    def get_account_nonce(self, address: Address) -> int:
+    def get_account_nonce(self, address: IAddress) -> int:
         url = f"{self.url}/address/{address.bech32()}"
         response = do_get(url)
         nonce = response.get("account").get("nonce", 0)
         return int(nonce)
 
-    def get_account_balance(self, address: Address):
+    def get_account_balance(self, address: IAddress):
         url = f"{self.url}/address/{address.bech32()}/balance"
         response = do_get(url)
         balance = response.get("balance", 0)
         return int(balance)
 
-    def get_account(self, address: Address):
+    def get_account(self, address: IAddress):
         url = f"{self.url}/address/{address.bech32()}"
         response = do_get(url)
         account = response.get("account", dict())
@@ -48,11 +49,18 @@ class ElrondProxy:
 
     def get_esdt_tokens(self, address: str) -> List:
         response = do_get(f"{self.url}/address/{address}/esdt")
-        return response.get("tokens")
+        esdts = response.get("esdts")
+        return cast(List, esdts)
 
     def get_esdt_balance(self, address: str, ticker: str) -> dict:
         response = do_get(f"{self.url}/address/{address}/esdt/{ticker}")
-        return response.get("tokenData")
+        token_data = response.get("tokenData")
+        return cast(dict, token_data)
+
+    def get_all_tokens(self) -> List[str]:
+        response = do_get(f"{self.url}/network/esdts")
+        tokens = response.get("tokens", [])
+        return cast(List[str], tokens)
 
     def get_num_shards(self):
         network_config = self.get_network_config()
@@ -91,12 +99,12 @@ class ElrondProxy:
     def send_transaction(self, payload: Any) -> str:
         url = f"{self.url}/transaction/send"
         response = do_post(url, payload)
-        tx_hash = response.get("txHash")
+        tx_hash = str(response.get("txHash"))
         return tx_hash
 
     def simulate_transaction(self, payload: Any) -> str:
         url = f"{self.url}/transaction/simulate"
-        response = do_post(url, payload)
+        response = str(do_post(url, payload))
         return response
 
     def send_transactions(self, payload: List[Any]) -> Tuple[int, List[str]]:
@@ -107,18 +115,19 @@ class ElrondProxy:
         hashes = response.get("txsHashes")
         return num_sent, hashes
 
-    def query_contract(self, payload: Any):
+    def query_contract(self, payload: Any) -> Any:
         url = f"{self.url}/vm-values/query"
         response = do_post(url, payload)
         return response
 
-    def get_transaction(self, tx_hash: str, sender_address: str = "", with_results: bool = False) -> Any:
+    def get_transaction(self, tx_hash: str, sender_address: str = "", with_results: bool = False) -> Dict[str, Any]:
         url = f"{self.url}/transaction/{tx_hash}"
         url += f"?sender={sender_address or ''}"
         url += f"&withResults={with_results}"
 
         response = do_get(url)
-        transaction = response.get("transaction", dict())
+        transaction_response = response.get("transaction", dict())
+        transaction = cast(Dict[str, Any], transaction_response)
         transaction['hash'] = tx_hash
         return transaction
 
@@ -131,7 +140,7 @@ class ElrondProxy:
         response = response.get("hyperblock", {})
         return response
 
-    def send_transaction_and_wait_for_result(self, payload: Any, num_seconds_timeout=100) -> str:
+    def send_transaction_and_wait_for_result(self, payload: Any, num_seconds_timeout: int = 100) -> Dict[str, Any]:
         url = f"{self.url}/transaction/send"
         response = do_post(url, payload)
         tx_hash = response.get("txHash")
@@ -140,7 +149,7 @@ class ElrondProxy:
             if self.is_transaction_finalized(tx_hash):
                 return self.get_transaction(tx_hash=tx_hash, with_results=True)
             time.sleep(1)
-        return ""
+        return dict()
 
     def is_transaction_finalized(self, tx_hash):
         last_nonce = self.get_last_block_nonce("metachain")
