@@ -63,6 +63,7 @@ async def do_start(args: Any):
     # Proxy
     to_run.append(run([
         "./proxy",
+        "--log-save"
     ], cwd=testnet_config.proxy_folder(), delay=PROXY_START_DELAY))
 
     await asyncio.gather(*to_run)
@@ -72,7 +73,7 @@ async def run(args, env=None, cwd: str = None, delay: int = 0):
     await asyncio.sleep(delay)
 
     process = await asyncio.create_subprocess_exec(*args, env=env, stdout=asyncio.subprocess.PIPE,
-                                                   stderr=asyncio.subprocess.PIPE, cwd=cwd)
+                                                   stderr=asyncio.subprocess.PIPE, cwd=cwd, limit=1024 * 512)
 
     pid = process.pid
 
@@ -102,8 +103,13 @@ async def _read_stream(stream, pid):
 
 def _patch_loglevel(loglevel: str) -> str:
     loglevel = loglevel or "*:DEBUG"
-    if "arwen/host:" not in loglevel:
-        loglevel += ",arwen/host:TRACE"
+    if "arwen:" not in loglevel:
+        loglevel += ",arwen:TRACE"
+    if "process/smartcontract:" not in loglevel:
+        loglevel += ",process/smartcontract:TRACE"
+
+    loglevel += ",*:TRACE"
+
     return loglevel
 
 
@@ -114,9 +120,9 @@ def _is_interesting_logline(logline):
         is_after_genesis = True
 
     if not is_after_genesis:
-        return any(e in logline for e in ["started committing block", "ERROR", "WARN"])    
-    return any(e in logline for e in ["started committing block", "ERROR", "WARN", "arwen"])
+        return any(e in logline for e in ["started committing block", "ERROR", "WARN"])
+    return any(e in logline for e in ["started committing block", "ERROR", "WARN", "arwen", "smartcontract"])
 
 
-def _dump_interesting_log_line(pid: str, logline: str) -> str:
+def _dump_interesting_log_line(pid: str, logline: str):
     print(f"[PID={pid}]", logline)
