@@ -2,11 +2,15 @@ import base64
 import json
 import logging
 from collections import OrderedDict
-from typing import Any, Dict
+from typing import Any, Dict, List, TextIO
 
 from erdpy import errors, utils
 from erdpy.accounts import Account, Address
 from erdpy.interfaces import IElrondProxy, ITransaction
+from erdpy.ledger.config import compare_versions
+from erdpy.ledger.ledger_app_handler import SIGN_USING_HASH_VERSION
+from erdpy.ledger.ledger_functions import do_get_ledger_version, TX_HASH_SIGN_VERSION, TX_HASH_SIGN_OPTIONS, \
+    do_sign_transaction_with_ledger
 from erdpy.wallet import signing
 
 logger = logging.getLogger("transactions")
@@ -26,6 +30,7 @@ class Transaction(ITransaction):
         self.data = ""
         self.chainID = ""
         self.version = 0
+        self.options = 0
         self.signature = ""
 
     # The data field is base64-encoded. erdpy only supports utf-8 "data" at this moment.
@@ -64,19 +69,19 @@ class Transaction(ITransaction):
         serialized = self._dict_to_json(dictionary)
         return serialized
 
-    def _dict_to_json(self, dictionary: Dict[str, Any]):
+    def _dict_to_json(self, dictionary: Dict[str, Any]) -> bytes:
         serialized = json.dumps(dictionary, separators=(',', ':')).encode("utf8")
         return serialized
 
-    def serialize_as_inner(self):
+    def serialize_as_inner(self) -> str:
         inner_dictionary = self.to_dictionary_as_inner()
         serialized = self._dict_to_json(inner_dictionary)
         serialized_hex = serialized.hex()
         return f"relayedTx@{serialized_hex}"
 
     @classmethod
-    def load_from_file(cls, f: Any):
-        data_json: bytes = utils.read_file(f).encode()
+    def load_from_file(cls, f: TextIO):
+        data_json: bytes = f.read().encode()
         fields = json.loads(data_json).get("tx")
         instance = cls()
         instance.__dict__.update(fields)
@@ -110,6 +115,7 @@ class Transaction(ITransaction):
         dictionary = self.to_dictionary()
         self.hash = proxy.send_transaction(dictionary)
         logger.info(f"Hash: {self.hash}")
+        utils.log_explorer_transaction(self.chainID, self.hash)
         return self.hash
 
     def send_wait_result(self, proxy, timeout):
@@ -147,7 +153,12 @@ class Transaction(ITransaction):
             dictionary["data"] = self.data_encoded()
 
         dictionary["chainID"] = self.chainID
-        dictionary["version"] = int(self.version)
+
+        if self.version:
+            dictionary["version"] = int(self.version)
+
+        if self.options:
+            dictionary["options"] = int(self.options)
 
         if self.signature:
             dictionary["signature"] = self.signature
@@ -171,12 +182,13 @@ class Transaction(ITransaction):
 
 class BunchOfTransactions:
     def __init__(self):
-        self.transactions = []
+        self.transactions: List[Transaction] = []
 
     def add_prepared(self, transaction: Transaction):
         self.transactions.append(transaction)
 
-    def add(self, sender: Account, receiver_address: str, nonce: Any, value: Any, data: str, gas_price: int, gas_limit: int, chain: str, version: int):
+    def add(self, sender: Account, receiver_address: str, nonce: Any, value: Any, data: str, gas_price: int,
+            gas_limit: int, chain: str, version: int, options: int):
         tx = Transaction()
         tx.nonce = int(nonce)
         tx.value = str(value)
@@ -187,6 +199,7 @@ class BunchOfTransactions:
         tx.data = data
         tx.chainID = chain
         tx.version = version
+        tx.options = options
 
         tx.sign(sender)
         self.transactions.append(tx)
@@ -205,6 +218,8 @@ class BunchOfTransactions:
 
 def do_prepare_transaction(args: Any) -> Transaction:
     account = Account()
+    if args.ledger:
+        return do_prepare_transaction_ledger(args)
     if args.pem:
         account = Account(pem_file=args.pem, pem_index=args.pem_index)
     elif args.keyfile and args.passfile:
@@ -222,6 +237,47 @@ def do_prepare_transaction(args: Any) -> Transaction:
     tx.data = args.data
     tx.chainID = args.chain
     tx.version = int(args.version)
+    tx.options = int(args.options)
 
     tx.sign(account)
     return tx
+
+
+def do_prepare_transaction_ledger(args: Any) -> Transaction:
+    account_index = 0
+    address_index = 0
+    if args.ledger_account_index:
+        account_index = args.ledger_account_index
+    if args.ledger_address_index:
+        address_index = args.ledger_address_index
+
+    tx = Transaction()
+    tx.nonce = int(args.nonce)
+    tx.value = args.value
+    tx.receiver = args.receiver
+    tx.sender = args.ledger_address
+    tx.senderUsername = getattr(args, "sender_username", None)
+    tx.receiverUsername = getattr(args, "receiver_username", None)
+    tx.gasPrice = int(args.gas_price)
+    tx.gasLimit = int(args.gas_limit)
+    tx.data = args.data
+    tx.chainID = args.chain
+
+    ledger_version = do_get_ledger_version()
+    should_use_hash_signing = compare_versions(ledger_version, SIGN_USING_HASH_VERSION) >= 0
+    if should_use_hash_signing:
+        tx.version = TX_HASH_SIGN_VERSION
+        tx.options = TX_HASH_SIGN_OPTIONS
+
+    tx.signature = ""
+
+    signature = do_sign_transaction_with_ledger(
+        tx_payload=tx.serialize(),
+        account_index=account_index,
+        address_index=address_index,
+        sign_using_hash=should_use_hash_signing,
+    )
+
+    tx.signature = signature
+
+    return tx
