@@ -9,7 +9,7 @@ import sys
 import tarfile
 import zipfile
 from pathlib import Path
-from typing import Any, Dict, List, Union
+from typing import Any, AnyStr, List, Union, Optional, cast, IO, Dict
 
 import toml
 
@@ -75,15 +75,35 @@ def read_lines(file: str):
     return lines
 
 
-def read_file(f: Any, binary=False) -> Union[str, bytes]:
+# TODO delete this function, it is too generic
+# TODO find usages in legolas
+def read_file(f: Any, binary: bool = False) -> Union[str, bytes]:
+    if isinstance(f, str) or isinstance(f, pathlib.PosixPath):
+        path = Path(f)
+        if binary:
+            return read_binary_file(path)
+        return read_text_file(path)
+
+    file = cast(IO, f)
+    result = file.read()
+    assert isinstance(result, str) or isinstance(result, bytes)
+    return result
+
+
+def read_binary_file(path: Path) -> bytes:
     try:
-        mode = "rb" if binary else "r"
-        if isinstance(f, str) or isinstance(f, pathlib.PosixPath):
-            with open(f, mode) as f:
-                return f.read()
-        return f.read()
+        with open(path, 'rb') as binary_file:
+            return binary_file.read()
     except Exception as err:
-        raise errors.BadFile(f, err)
+        raise errors.BadFile(str(path), err) from None
+
+
+def read_text_file(path: Path) -> str:
+    try:
+        with open(path, 'r') as text_file:
+            return text_file.read()
+    except Exception as err:
+        raise errors.BadFile(str(path), err) from None
 
 
 def write_file(f: Any, text: str):
@@ -102,9 +122,11 @@ def write_toml_file(filename, data):
         toml.dump(data, f)
 
 
-def read_json_file(filename: str) -> Dict[str, Any]:
+def read_json_file(filename: Union[str, Path]) -> Dict[str, Any]:
+    data: Dict[str, Any]
     with open(filename) as f:
-        return json.load(f)
+        data = json.load(f)
+    return data
 
 
 def write_json_file(filename: str, data: Any):
@@ -146,7 +168,7 @@ def find_in_dictionary(dictionary, compound_path):
     return node
 
 
-def list_files(folder: str, suffix: str = None) -> List[str]:
+def list_files(folder: Union[str, Path], suffix: Optional[str] = None) -> List[str]:
     files = os.listdir(folder)
     files = [os.path.join(folder, f) for f in files]
 
@@ -156,7 +178,7 @@ def list_files(folder: str, suffix: str = None) -> List[str]:
     return files
 
 
-def remove_folder(folder):
+def remove_folder(folder: Union[str, Path]):
     shutil.rmtree(folder, ignore_errors=True)
 
 
@@ -166,20 +188,16 @@ def symlink(real: str, link: str) -> None:
     os.symlink(real, link)
 
 
-def str_to_bool(input: str) -> bool:
-    return str(input).lower() in ["true", "1", "t", "y", "yes"]
-
-
-def as_object(input: Any) -> Object:
-    if isinstance(input, dict):
+def as_object(data: Object) -> Object:
+    if isinstance(data, dict):
         result = Object()
-        result.__dict__.update(input)
+        result.__dict__.update(data)
         return result
 
-    return input
+    return data
 
 
-def is_arg_present(key: str, args: List[str]) -> bool:
+def is_arg_present(args: List[str], key: str) -> bool:
     for arg in args:
         if arg.find("--data") != -1:
             continue
@@ -189,6 +207,24 @@ def is_arg_present(key: str, args: List[str]) -> bool:
     return False
 
 
+def str_int_to_hex_str(number_str: str) -> str:
+    num_of_bytes = 1
+    if len(number_str) > 2:
+        num_of_bytes = int(len(number_str) / 2)
+    int_str = int(number_str)
+    int_bytes = int_str.to_bytes(num_of_bytes, byteorder="big")
+    bytes_str = int_bytes.hex()
+    return bytes_str
+
+
+def parse_keys(bls_public_keys):
+    keys = bls_public_keys.split(',')
+    parsed_keys = ''
+    for key in keys:
+        parsed_keys += '@' + key
+    return parsed_keys, len(keys)
+
+
 # https://code.visualstudio.com/docs/python/debugging
 def breakpoint():
     import debugpy
@@ -196,3 +232,24 @@ def breakpoint():
     print("Waiting for debugger attach")
     debugpy.wait_for_client()
     debugpy.breakpoint()
+
+
+def log_explorer(chain, name, path, details):
+    networks = {
+        "1": ("Elrond Mainnet Explorer", "https://explorer.elrond.com"),
+        "T": ("Elrond Testnet Explorer", "https://testnet-explorer.elrond.com"),
+        "D": ("Elrond Devnet Explorer", "https://devnet-explorer.elrond.com"),
+    }
+    try:
+        explorer_name, explorer_url = networks[chain]
+        logger.info(f"View this {name} in the {explorer_name}: {explorer_url}/{path}/{details}")
+    except KeyError:
+        return
+
+
+def log_explorer_contract_address(chain, address):
+    log_explorer(chain, "contract address", "accounts", address)
+
+
+def log_explorer_transaction(chain, transaction_hash):
+    log_explorer(chain, "transaction", "transactions", transaction_hash)
